//
//  LineMarkerController.m
//  LineMarkerSample
//
//  Created by kelley.ricker on 11/12/15.
//  Copyright © 2015 GrapeCity. All rights reserved.
//

#import "LineMarkerController.h"
#import "XuniFlexChartKit/XuniFlexChartKit.h"
#import "ChartData.h"
@interface LineMarkerController (){
    UIPickerView *chartTypePicker;
    UIPickerView *stackingPicker;
    UITextField *chartEntryField;
    UITextField *stackingEntryField;
    NSMutableArray *chartTypePickerData;
    NSMutableArray *stackingPickerData;
    FlexChart *chart;
}
@end

@implementation LineMarkerController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.edgesForExtendedLayout = UIRectEdgeNone;
    self.title = @"Line Marker Sample";
    chartTypePicker = [[UIPickerView alloc] init];
    stackingPicker = [[UIPickerView alloc] init];
    
    chartEntryField = [[UITextField alloc] init];
    
    stackingEntryField = [[UITextField alloc] init];
    
    chartEntryField.backgroundColor = [UIColor colorWithRed:0.88 green:0.88 blue:0.88 alpha:1.0];
    stackingEntryField.backgroundColor = [UIColor colorWithRed:0.88 green:0.88 blue:0.88 alpha:1.0];
    chartTypePickerData =[[NSMutableArray alloc] initWithObjects: @"Area", @"SplineArea", nil];
    stackingPickerData = [[NSMutableArray alloc]initWithObjects: @"None", @"Stacked", @"Stacked100pc", nil];
    chart = [[FlexChart alloc] init];
    NSMutableArray *chartData = [ChartData demoDateData];
    
    chartTypePicker.delegate = self;
    chartTypePicker.showsSelectionIndicator = YES;
    chartTypePicker.hidden = false;
    chartTypePicker.tag = 1;
    
    stackingPicker.delegate = self;
    stackingPicker.showsSelectionIndicator = YES;
    stackingPicker.hidden = false;
    stackingPicker.tag = 2;
    
    chartEntryField.tag = 3;
    stackingEntryField.tag = 4;
    chart.zoomMode = XuniZoomModeXY;
    
    chart.bindingX = @"date";
    XuniSeries *sales = [[XuniSeries alloc] initForChart:chart binding:@"sales, sales" name:@"Sandals"];
    XuniSeries *expenses = [[XuniSeries alloc] initForChart:chart binding:@"expenses, expenses" name:@"Wetsuits"];
    XuniSeries *downloads = [[XuniSeries alloc] initForChart:chart binding:@"downloads, downloads" name:@"Surfboards"];
    
    [chart.series addObject:sales];
    [chart.series addObject:expenses];
    [chart.series addObject:downloads];
    
    chart.itemsSource = chartData;
    chart.axisX.labelAngle = 25;
    chart.axisX.labelsVisible = true;
    chart.axisY.labelsVisible = true;
    chart.legend.orientation = XuniChartLegendOrientationAuto;
    chart.legend.position = XuniChartLegendPositionBottom;
    chart.chartType = XuniChartTypeArea;
    chart.selectedDashes = @[@15, @5];
    chart.selectedBorderWidth = 4;
    chart.stacking = XuniStackingStacked;
    chart.tooltip.isVisible = false;
    chart.palette = [XuniPalettes modern];
    chartEntryField.inputView = chartTypePicker;
    chartEntryField.text = [chartTypePickerData objectAtIndex:0];
    chart.loadAnimation.duration = 0;
    
    MyMarkerView *view = [[MyMarkerView alloc] initWithLineMarker:chart.lineMarker];
    view.markerRender = [[MyChartMarkerRender alloc] initWithView:view];
    [chart addSubview:view];
    chart.lineMarker.content = view;
    chart.lineMarker.isVisible = true;
    chart.lineMarker.alignment = XuniChartMarkerAlignmentAuto;
    chart.lineMarker.lines = XuniChartMarkerLinesBoth;
    chart.lineMarker.interaction= XuniChartMarkerInteractionMove;
    chart.lineMarker.dragContent = true;
    chart.lineMarker.seriesIndex = 2;
    chart.lineMarker.verticalLineColor = [UIColor grayColor];
    
    
    UIToolbar *toolbar = [[UIToolbar alloc] initWithFrame:CGRectMake(0, 0, self.view.frame.size.width, 44)];
    UIBarButtonItem *done = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemDone target:self action:@selector(endEditPicker:)];
    UIBarButtonItem *space = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemFlexibleSpace target:nil action:nil];
    [toolbar setItems:@[space, done]];
    chartEntryField.inputAccessoryView = toolbar;
    
    stackingEntryField.inputView = stackingPicker;
    stackingEntryField.text = [stackingPickerData objectAtIndex:1];
    stackingEntryField.inputAccessoryView = toolbar;
    
    [self.view addSubview:chartEntryField];
    [self.view addSubview:stackingEntryField];
    [self.view addSubview:chart];
    
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}
-(void)viewDidLayoutSubviews{
    [super viewDidLayoutSubviews];
    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        chartEntryField.frame = CGRectMake(5, 5, (self.view.bounds.size.width-10)/4, 40);
        stackingEntryField.frame = CGRectMake(self.view.bounds.size.width/2 + 5, 5, (self.view.bounds.size.width-10)/4, 40);
    }
    else{
        chartEntryField.frame = CGRectMake(5, 5, self.view.bounds.size.width / 2 - 10, 40);
        stackingEntryField.frame = CGRectMake(self.view.bounds.size.width / 2 + 5, 5, self.view.bounds.size.width / 2 - 10, 40);
    }

    chart.frame = CGRectMake(0, 50, self.view.bounds.size.width, self.view.bounds.size.height - 50);
}

- (BOOL)endEditPicker:(UITextField *)textField {
    [chartEntryField endEditing:true];
    [stackingEntryField endEditing:true];
    return true;
}

- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView{
    return 1;
}

- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component{
    
    if(pickerView.tag == 1){
        return [chartTypePickerData count];
    }
    else{
        return [stackingPickerData count];
    }
}

- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component{
    
    if(pickerView.tag == 1)
    {
        if (row == 0) {
            chart.chartType = XuniChartTypeArea;
        }
        else if (row == 1){
            chart.chartType = XuniChartTypeSplineArea;
        }
        chartEntryField.text = [chartTypePickerData objectAtIndex:row];
    }
    else if(pickerView.tag == 2){
        if (row == 0) {
            chart.stacking = XuniStackingNone;
            
        }
        else if (row == 1){
            chart.stacking= XuniStackingStacked;
        }
        else if (row == 2){
            chart.stacking = XuniStackingStacked100pc;
        }
        stackingEntryField.text = [stackingPickerData objectAtIndex:row];
    }
    [self setAxisFormatting];
}
-(void)setAxisFormatting{
    if (chart.chartType == XuniChartTypeBar) {
        if (chart.stacking == XuniStackingStacked100pc  && chart.rotated == false) {
            chart.axisX.format = @"p";
            chart.axisY.format = @"d";
        }
        else if (chart.stacking == XuniStackingStacked100pc  && chart.rotated == true){
            chart.axisX.format = @"d";
            chart.axisY.format = @"p";
        }
        else{
            chart.axisX.format = @"d";
            chart.axisY.format = @"d";
        }
    }
    else{
        if(chart.stacking == XuniStackingStacked100pc && chart.rotated == false){
            chart.axisX.format = @"d";
            chart.axisY.format = @"p";
        }
        else if(chart.stacking == XuniStackingStacked100pc && chart.rotated == true){
            chart.axisX.format = @"p";
            chart.axisY.format = @"d";
        }
        else{
            chart.axisX.format = @"d";
            chart.axisY.format = @"d";
        }
    }
}

- (NSString*)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component{
    if(pickerView.tag == 1)
    {
        return [chartTypePickerData objectAtIndex:row];
    }
    else if(pickerView.tag == 2){
        return [stackingPickerData objectAtIndex:row];
    }
    else{
        return @"error";
    }
}

/*
 #pragma mark - Navigation
 
 // In a storyboard-based application, you will often want to do a little preparation before navigation
 - (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
 // Get the new view controller using [segue destinationViewController].
 // Pass the selected object to the new view controller.
 }
 */

@end

// Class MyMarkerView
@implementation MyMarkerView

- (id)initWithLineMarker:(XuniChartLineMarker *)lineMarker {
    self = [super initWithLineMarker:lineMarker];
    if (self) {
        _lineMarker = lineMarker;
        
        self.backgroundColor = [UIColor colorWithWhite:0.8 alpha:0.6];
        self.frame = CGRectMake(0, 0, 125, 60);
        
        _content = [[UILabel alloc] init];
        _content.frame = CGRectMake(5, 5, 115, 50);
        _content.backgroundColor = [UIColor clearColor];
        _content.font = [UIFont systemFontOfSize:10.0];
        [self addSubview:_content];
    }
    
    return self;
}

@end


// Class MyChartMarkerRender
@implementation MyChartMarkerRender {
    XuniChartMarkerBaseView *_view;
}

- (id)initWithView:(XuniChartMarkerBaseView *)view {
    _view = view;
    return self;
}

- (void)renderMarker {
    if (_view != nil ) {
        MyMarkerView *view = (MyMarkerView *)_view;
        NSArray *data = view.lineMarker.dataPoints;
        
        if (data != nil && data.count > 0) {
            NSString *str = @"";
            XuniDataPoint *point = data[0];
            str = [str stringByAppendingFormat:@"%@ \n", point.dataXString];
            
            for (int i = 0; i < data.count - 1; i++) {
                point = data[i];
                str = [str stringByAppendingFormat:@"%@ : %.2f \n", point.seriesName, point.dataY];
            }
            point = data[data.count - 1];
            str = [str stringByAppendingFormat:@"%@ : %.2f", point.seriesName, point.dataY];
            
            view.content.text = str;
            view.content.numberOfLines = 4;
        }
    }
}

@end
